retex v0.1.8 Retex.Node.NegativeType View Source

The NegativeNodeType if part of the alpha network, the discrimination part of the network that check if a specific class DOES NOT exist. If this is the case, it propagates the activations down to the select node types. They will select an attribute and check for its test to pass.

Link to this section Summary

Link to this section Types

Link to this type

t()

t() :: %Retex.Node.Type{
  bindings: term(),
  class: term(),
  id: term(),
  type: term()
}

Link to this section Functions

Link to this function

new(class, labels \\ [])

View Source