retex v0.1.8 Retex.Node.SelectNot View Source

The select nodes are checking for attributes, if they do NOT exists and are linked to the right owner from above, they will be activated and pass the tokens down

Link to this section Summary

Link to this section Types

Link to this type

t()

t() :: %Retex.Node.SelectNot{
  bindings: term(),
  class: term(),
  id: term(),
  parent: term(),
  type: term()
}

Link to this section Functions

Link to this function

new(parent, class, labels \\ [])

View Source